package eu.devity.vaultconnector

import io.swagger.v3.oas.models.OpenAPI
import io.swagger.v3.oas.models.info.Info
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.beans.factory.annotation.Value
import org.springframework.boot.info.BuildProperties
import org.springframework.context.annotation.Bean
import org.springframework.context.annotation.Configuration
import org.springframework.core.io.InputStreamResource
import org.springframework.vault.authentication.ClientAuthentication
import org.springframework.vault.authentication.TokenAuthentication
import org.springframework.vault.client.VaultEndpoint
import org.springframework.vault.config.AbstractVaultConfiguration
import org.springframework.vault.support.SslConfiguration
import java.io.File
import java.net.URI

@Configuration
class VaultConfiguration(
    @Value("\${vault.uri}") private val vaultUri: URI,
    @Value("\${vault.token}") private val vaultToken: String,
    @Value("\${vault.pki-managed-path}") private val pkiManagedPath: String,
    @Value("\${vault.ssl.trust-store}") private val trustStore: String,
    @Value("\${vault.ssl.trust-store-password}") private val trustStorePwd: String,
    @Value("\${vault.ssl.trust-store-type}") private val trustStoreType: String
) : AbstractVaultConfiguration() {

    @Autowired(required = false)
    private var buildInfo: BuildProperties? = null

    override fun vaultEndpoint(): VaultEndpoint = VaultEndpoint.from(vaultUri)

    override fun clientAuthentication(): ClientAuthentication =
        TokenAuthentication(vaultToken)

    @Bean
    fun customOpenAPI(): OpenAPI? {
        return OpenAPI().info(
            Info().title("Devity Vault Spring Adapter")
                .version(buildInfo?.version)
                .description("This is an initial version of Vault Spring Adapter")
        )
    }

    override fun sslConfiguration(): SslConfiguration {
        val resource = InputStreamResource(File(trustStore).inputStream())
        val trustStore: SslConfiguration.KeyStoreConfiguration =
            SslConfiguration.KeyStoreConfiguration(
                resource,
                trustStorePwd.toCharArray(),
                trustStoreType
            )
        return SslConfiguration(
            SslConfiguration.KeyStoreConfiguration.unconfigured(),
            trustStore
        )
    }

    @Bean
    fun pkiManagedPath(): String = pkiManagedPath
}
