package eu.devity.vaultconnector.controller

import eu.devity.vaultconnector.serializable.CreateOrUpdateRoleRequest
import org.springframework.http.HttpEntity
import org.springframework.http.HttpMethod
import org.springframework.http.HttpStatus
import org.springframework.vault.VaultException
import org.springframework.vault.core.VaultTemplate
import org.springframework.web.bind.annotation.*
import org.springframework.web.client.HttpClientErrorException
import org.springframework.web.util.UriUtils

@RestController
@RequestMapping("/roles")
class RoleController(
    val vaultTemplate: VaultTemplate,
) {
    @PostMapping("/{roleName}")
    @PutMapping("/{roleName}")
    @ResponseStatus(HttpStatus.CREATED)
    fun createOrUpdateRole(
        @RequestParam("pkiPath") urlEncodedPkiPath: String,
        @PathVariable("roleName") roleName: String,
        @RequestBody(required = true) roleOptions: CreateOrUpdateRoleRequest
    ) {
        val pkiPath = UriUtils.decode(urlEncodedPkiPath, "ASCII")

        vaultTemplate.doWithSession {
            it.exchange(
                "{pkiPath}/roles/{roleName}",
                HttpMethod.POST,
                HttpEntity(roleOptions),
                String::class.java,
                mapOf("pkiPath" to pkiPath, "roleName" to roleName)
            )
        }
    }

    @ExceptionHandler(VaultException::class)
    @ResponseStatus(HttpStatus.BAD_REQUEST)
    fun handleVaultException(e: VaultException): String =
        when (val rootCause = e.rootCause) {
            is HttpClientErrorException ->
                when {
                    rootCause.statusCode.is4xxClientError ->
                        "bad request from Vault server: ${rootCause.message}"
                    else -> throw e
                }
            else -> throw e
        }
}
