package eu.devity.vaultconnector.serializable

import com.fasterxml.jackson.annotation.JsonInclude
import com.fasterxml.jackson.databind.PropertyNamingStrategy
import com.fasterxml.jackson.databind.annotation.JsonNaming
import io.swagger.v3.oas.annotations.media.Schema

enum class CAType {
    INTERNAL, EXTERNAL
}

@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonNaming(PropertyNamingStrategy.SnakeCaseStrategy::class)
data class CreateCARequest(
    @Schema(description = "Type of CA to be created.\n'INTERNAL' means both root and intermediate CAs will be managed by Vault.\n'EXTERNAL' means only intermediate CA is managed by Vault", example = "INTERNAL")
    val caType: CAType,
    @Schema(description = "Root CA validity period, default to 10 years (87600h)", example = "87600h")
    val rootTTl: String?,
    @Schema(description = "Intermediate CA validity period, default to 5 years (43800h)", example = "43800h")
    val intermediateTTL: String?,
    @Schema(description = "Public key algorithm; 'ec' or 'rsa'", example = "ec")
    val keyType: String?,
    @Schema(description = "Bit length of the key", example = "348")
    val keyBits: Int?,
    @Schema(description = "Distinguished name and extensions", example = "")
    val csrFields: CsrRequest?
)
