package eu.devity.vaultconnector.serializable

import com.fasterxml.jackson.annotation.JsonInclude
import com.fasterxml.jackson.databind.PropertyNamingStrategy
import com.fasterxml.jackson.databind.annotation.JsonNaming
import io.swagger.v3.oas.annotations.media.Schema

@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonNaming(PropertyNamingStrategy.SnakeCaseStrategy::class)
data class CreateOrUpdateRoleRequest(
    @Schema(description = "Describes the Time To Live value provided as a string duration with time suffix", example = "300h")
    val ttl: String?,
    @Schema(description = "Describes the maximum Time To Live provided as a string duration with time suffix", example = "87600h")
    val maxTtl: String?,
    @Schema(description = "Describes if clients can request certificates for localhost as one of the requested common names", example = "true")
    val allowLocalhost: Boolean?,
    @Schema(description = "Describes the domains of the role", example = "[\"example.com\"]")
    val allowedDomains: List<String>?,

    // allow_domains_template
    @Schema(description = "Describes if clients can request certificates matching the value of the actual domains themselves", example = "false")
    val allowBareDomains: Boolean?,
    @Schema(description = "Describes if clients can request certificates with CNs that are subdomains of the CNs allowed by the other role options", example = "false")
    val allowSubdomains: Boolean?,

    // allow_glob_domains
    @Schema(description = "Describes if clients can request any CN", example = "false")
    val allowAnyName: Boolean?,
    @Schema(description = "Describes if only valid host names are allowed for CNs etc", example = "true")
    val enforceHostnames: Boolean?,
    @Schema(description = "Describes if clients can request IP Subject Alternative Names", example = "true")
    val allowIpSans: Boolean?,

    // allowed_uri_sans
    // allowed_other_sans
    @Schema(description = "Describes if certificates are flagged for server use", example = "true")
    val serverFlag: Boolean?,
    @Schema(description = "Describes if certificates are flagged for client use", example = "true")
    val clientFlag: Boolean?,
    @Schema(description = "Describes if certificates are flagged for code signing use", example = "false")
    val codeSigningFlag: Boolean?,
    @Schema(description = "Describes if certificates are flagged for email protection use", example = "false")
    val emailProtectionFlag: Boolean?,
    @Schema(description = "Describes the type of key to generate for generated private keys and the type of key expected for submitted CSRs", example = "ec")
    val keyType: String?,
    @Schema(description = "Describes the number of bits to use for the generated keys", example = "384")
    val keyBits: Long?,
    @Schema(description = "Describes the allowed key usage constraint on issued certificates", example = "[\"DigitalSignature\", \"KeyAgreement\", \"KeyEncipherment\"]")
    val keyUsage: List<String>?,
    @Schema(description = "Describes the allowed extended key usage constraint on issued certificates", example = "")
    val extKeyUsage: List<String>?,
    @Schema(description = "When specified in CSR, the CN in the CSR will be used instead of taken from the JSON data.", example = "true")
    val useCsrCommonName: Boolean?,

    // ext_key_usage_oids
    @Schema(description = " When specified in CSR, the SAN in the CSR will be used instead of taken from the JSON data", example = "true")
    val useCsrSans: Boolean?,

    // ou
    // organization
    // country
    // locality
    // province
    // street_address
    // postal_code
    // serial_number
    // generate_lease
    // no_store
    // require_cn
    // policy_identifiers
    // basic_constraints_valid_for_non_ca
    // not_before_duration
)
