package eu.devity.vaultconnector.serializable

import com.fasterxml.jackson.annotation.JsonInclude
import com.fasterxml.jackson.databind.PropertyNamingStrategy
import com.fasterxml.jackson.databind.annotation.JsonNaming
import io.swagger.v3.oas.annotations.media.Schema

@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonNaming(PropertyNamingStrategy.SnakeCaseStrategy::class)
data class CsrRequest(
    @Schema(description = "Subject alternative names (SANs), in a comma-delimited list", example = "exmaple.com")
    val altNames: String? = null,
    @Schema(description = "IP SANs, in a comma-delimited list", example = "192.168.0.1")
    val ipSans: String? = null,
    @Schema(description = "URI SANs, in a comma-delimited list", example = "")
    val uriSans: String? = null,
    @Schema(description = "Custom OID/UTF8-string SANs", example = "<oid>;<type>:<value>")
    val otherSans: String? = null,
    @Schema(description = "Organization unit", example = "Research & Development")
    val ou: String? = null,
    @Schema(description = "Organization name", example = "DEVITY")
    val organization: String? = null,
    @Schema(description = "Country", example = "DE")
    val country: String? = null,
    @Schema(description = "City/Locality", example = "Paderborn")
    val locality: String? = null,
    @Schema(description = "State/Province", example = "NRW")
    val province: String? = null,
    @Schema(description = "Address", example = "31 Samplestraße")
    val street_address: String? = null,
    @Schema(description = "Postal code", example = "34000")
    val postal_code: String? = null,
)
